dj-bootstrap-components
============================

Django Bootstrap components

.. image:: https://api.travis-ci.com/IshanManchanda/dj-bootstrap-components.svg?branch=master
  :target: https://travis-ci.com/IshanManchanda/dj-bootstrap-components

.. image:: https://readthedocs.org/projects/dj-bootstrap-components/badge/?version=latest
  :target: https://dj-bootstrap-components.readthedocs.io/en/latest/?badge=latest

.. image:: https://badge.fury.io/py/dj-bootstrap-components.svg
  :target: https://badge.fury.io/py/dj-bootstrap-components

.. image:: https://img.shields.io/pypi/dm/dj-bootstrap-components


Quick start
-----------

Documentation: https://dj-bootstrap-components.readthedocs.io/en/latest/

1. Add "bootstrap_components" to your INSTALLED_APPS setting like this::

	INSTALLED_APPS = [
		...
		'bootstrap_components',
	]

2. TODO: Write this

3. ???

4. Profit
